Documentation
¶
Index ¶
- type Agent
- type AggregatedDuration
- type Child
- type Client
- type Cloud
- type CloudAccount
- type CloudInstance
- type CloudMachine
- type CloudOrigin
- type CloudProject
- type CloudService
- type Code
- type Container
- type ContainerImage
- type DB
- type DBUser
- type DataStream
- type Destination
- type Device
- type DeviceModel
- type Document
- type DroppedSpanStats
- type Error
- type ErrorLog
- type Event
- type Exception
- type FAAS
- type FAASTrigger
- type Framework
- type HTTP
- type HTTPHeaders
- type HTTPRequest
- type HTTPRequestBody
- type HTTPResponse
- type Histogram
- type Host
- type IP
- type KeyValueSlice
- type Kubernetes
- type KubernetesNode
- type KubernetesPod
- type Label
- type Language
- type Log
- type LogOrigin
- type LogOriginFile
- type LongtaskMetrics
- type Message
- type MessageAge
- type MessageQueue
- type Metricset
- type MetricsetSample
- type NAT
- type Network
- type NetworkCarrier
- type NetworkConnection
- type NumericLabel
- type OS
- type Observer
- type Parent
- type Process
- type ProcessParent
- type ProcessThread
- type Runtime
- type Service
- type ServiceNode
- type ServiceOrigin
- type ServiceTarget
- type Session
- type Source
- type Span
- type SpanComposite
- type SpanCompositeSum
- type SpanCount
- type SpanDestination
- type SpanDestinationService
- type SpanLink
- type SpanLinkSpan
- type SpanLinkTrace
- type StacktraceFrame
- type StacktraceFrameContext
- type StacktraceFrameLine
- type StacktraceFrameOriginal
- type StacktraceFrameSourcemap
- type SummaryMetric
- type System
- type SystemFilesystem
- type SystemProcess
- type SystemProcessCPU
- type Time
- type Timestamp
- type Trace
- type Transaction
- type URL
- type User
- type UserAgent
- type UserExperience
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Agent ¶
type Agent struct {
Name string `json:"name,omitempty"`
Version string `json:"version,omitempty"`
EphemeralID string `json:"ephemeral_id,omitempty"`
ActivationMethod string `json:"activation_method,omitempty"`
}
Agent describes an Elastic APM agent.
type AggregatedDuration ¶
func (AggregatedDuration) MarshalFastJSON ¶
func (d AggregatedDuration) MarshalFastJSON(w *fastjson.Writer) error
type Child ¶
type Child struct {
// ID holds IDs of child events.
ID []string `json:"id,omitempty"`
}
Child holds information about the children of a trace event.
type Client ¶
type Client struct {
IP string `json:"ip,omitempty"`
Domain string `json:"domain,omitempty"`
Port int `json:"port,omitempty"`
}
Client holds information about the client of a request.
type Cloud ¶
type Cloud struct {
AvailabilityZone string `json:"availability_zone,omitempty"`
Provider string `json:"provider,omitempty"`
Region string `json:"region,omitempty"`
Origin CloudOrigin `json:"origin,omitempty"`
Account CloudAccount `json:"account,omitempty"`
Instance CloudInstance `json:"instance,omitempty"`
Machine CloudMachine `json:"machine,omitempty"`
Project CloudProject `json:"project,omitempty"`
Service CloudService `json:"service,omitempty"`
}
type CloudAccount ¶
func (*CloudAccount) MarshalFastJSON ¶
func (v *CloudAccount) MarshalFastJSON(w *fastjson.Writer) error
type CloudInstance ¶
func (*CloudInstance) MarshalFastJSON ¶
func (v *CloudInstance) MarshalFastJSON(w *fastjson.Writer) error
type CloudMachine ¶
type CloudMachine struct {
Type string `json:"type,omitempty"`
}
func (*CloudMachine) MarshalFastJSON ¶
func (v *CloudMachine) MarshalFastJSON(w *fastjson.Writer) error
type CloudOrigin ¶
type CloudOrigin struct {
Account CloudAccount `json:"account,omitempty"`
Provider string `json:"provider,omitempty"`
Region string `json:"region,omitempty"`
Service CloudService `json:"service,omitempty"`
}
func (*CloudOrigin) MarshalFastJSON ¶
func (v *CloudOrigin) MarshalFastJSON(w *fastjson.Writer) error
type CloudProject ¶
func (*CloudProject) MarshalFastJSON ¶
func (v *CloudProject) MarshalFastJSON(w *fastjson.Writer) error
type CloudService ¶
type CloudService struct {
Name string `json:"name"`
}
func (*CloudService) MarshalFastJSON ¶
func (v *CloudService) MarshalFastJSON(w *fastjson.Writer) error
type Container ¶
type Container struct {
ID string `json:"id,omitempty"`
Name string `json:"name,omitempty"`
Runtime string `json:"runtime,omitempty"`
Image ContainerImage `json:"image,omitempty"`
}
type ContainerImage ¶
type ContainerImage struct {
Name string `json:"name,omitempty"`
Tag string `json:"tag,omitempty"`
}
func (*ContainerImage) MarshalFastJSON ¶
func (v *ContainerImage) MarshalFastJSON(w *fastjson.Writer) error
type DB ¶
type DataStream ¶
type DataStream struct {
Type string `json:"type,omitempty"`
Dataset string `json:"dataset,omitempty"`
Namespace string `json:"namespace,omitempty"`
}
func (*DataStream) MarshalFastJSON ¶
func (v *DataStream) MarshalFastJSON(w *fastjson.Writer) error
type Destination ¶
type Destination struct {
Address string `json:"address,omitempty"`
// TODO(axw) add a "convert" ingest processor to pipelines,
// copying destination.address to destination.ip if it's a
// valid IP, and remove this field.
IP string `json:"ip,omitempty"`
Port int `json:"port,omitempty"`
}
func (*Destination) MarshalFastJSON ¶
func (v *Destination) MarshalFastJSON(w *fastjson.Writer) error
type Device ¶
type Device struct {
ID string `json:"id,omitempty"`
Model DeviceModel `json:"model,omitempty"`
Manufacturer string `json:"manufacturer,omitempty"`
}
type DeviceModel ¶
type DeviceModel struct {
Name string `json:"name,omitempty"`
Identifier string `json:"identifier,omitempty"`
}
func (*DeviceModel) MarshalFastJSON ¶
func (v *DeviceModel) MarshalFastJSON(w *fastjson.Writer) error
type Document ¶
type Document struct {
Span *Span `json:"span,omitempty"`
Transaction *Transaction `json:"transaction,omitempty"`
Metricset *Metricset `json:"metricset,omitempty"`
Error *Error `json:"error,omitempty"`
TimestampStruct *Timestamp `json:"timestamp,omitempty"`
Labels map[string]Label `json:"labels,omitempty"`
NumericLabels map[string]NumericLabel `json:"numeric_labels,omitempty"`
Cloud *Cloud `json:"cloud,omitempty"`
Service *Service `json:"service,omitempty"`
FAAS *FAAS `json:"faas,omitempty"`
Network *Network `json:"network,omitempty"`
Container *Container `json:"container,omitempty"`
User *User `json:"user,omitempty"`
Device *Device `json:"device,omitempty"`
Kubernetes *Kubernetes `json:"kubernetes,omitempty"`
Observer *Observer `json:"observer,omitempty"`
Agent *Agent `json:"agent,omitempty"`
HTTP *HTTP `json:"http,omitempty"`
UserAgent *UserAgent `json:"user_agent,omitempty"`
Parent *Parent `json:"parent,omitempty"`
Trace *Trace `json:"trace,omitempty"`
Host *Host `json:"host,omitempty"`
URL *URL `json:"url,omitempty"`
Log *Log `json:"log,omitempty"`
Source *Source `json:"source,omitempty"`
Client *Client `json:"client,omitempty"`
Child *Child `json:"child,omitempty"`
Destination *Destination `json:"destination,omitempty"`
Session *Session `json:"session,omitempty"`
Process *Process `json:"process,omitempty"`
Event *Event `json:"event,omitempty"`
Code *Code `json:"code,omitempty"`
System *System `json:"system,omitempty"`
Timestamp Time `json:"@timestamp"`
DataStream *DataStream `json:"data_stream,omitempty"`
Message string `json:"message,omitempty"`
DocCount uint64 `json:"_doc_count,omitempty"`
}
Document is the Elasticsearch JSON document representation of an APM event.
type DroppedSpanStats ¶
type DroppedSpanStats struct {
DestinationServiceResource string `json:"destination_service_resource,omitempty"`
ServiceTargetType string `json:"service_target_type,omitempty"`
ServiceTargetName string `json:"service_target_name,omitempty"`
Outcome string `json:"outcome,omitempty"`
Duration AggregatedDuration `json:"duration,omitempty"`
}
func (*DroppedSpanStats) MarshalFastJSON ¶
func (v *DroppedSpanStats) MarshalFastJSON(w *fastjson.Writer) error
type Error ¶
type Error struct {
Exception *Exception `json:"exception,omitempty"`
Log *ErrorLog `json:"log,omitempty"`
ID string `json:"id,omitempty"`
GroupingKey string `json:"grouping_key,omitempty"`
Culprit string `json:"culprit,omitempty"`
Message string `json:"message,omitempty"`
Type string `json:"type,omitempty"`
StackTrace string `json:"stack_trace,omitempty"`
Custom KeyValueSlice `json:"custom,omitempty"`
}
type ErrorLog ¶
type ErrorLog struct {
Message string `json:"message,omitempty"`
Level string `json:"level,omitempty"`
ParamMessage string `json:"param_message,omitempty"`
LoggerName string `json:"logger_name,omitempty"`
Stacktrace []StacktraceFrame `json:"stacktrace,omitempty"`
}
type Event ¶
type Event struct {
Outcome string `json:"outcome,omitempty"`
Action string `json:"action,omitempty"`
Dataset string `json:"dataset,omitempty"`
Kind string `json:"kind,omitempty"`
Category string `json:"category,omitempty"`
Module string `json:"module,omitempty"`
Received Time `json:"received,omitempty"`
Type string `json:"type,omitempty"`
SuccessCount SummaryMetric `json:"success_count,omitempty"`
Duration uint64 `json:"duration,omitempty"`
Severity uint64 `json:"severity,omitempty"`
}
type Exception ¶
type Exception struct {
Message string
Module string
Code string
Attributes KeyValueSlice
Stacktrace []StacktraceFrame
Type string
Handled *bool
Cause []Exception
}
type FAAS ¶
type FAASTrigger ¶
type FAASTrigger struct {
Type string `json:"type,omitempty"`
RequestID string `json:"request_id,omitempty"`
}
func (*FAASTrigger) MarshalFastJSON ¶
func (v *FAASTrigger) MarshalFastJSON(w *fastjson.Writer) error
type Framework ¶
type HTTP ¶
type HTTP struct {
Request *HTTPRequest `json:"request,omitempty"`
Response *HTTPResponse `json:"response,omitempty"`
Version string `json:"version,omitempty"`
}
type HTTPHeaders ¶
type HTTPHeaders []*modelpb.HTTPHeader
func (*HTTPHeaders) MarshalFastJSON ¶
func (s *HTTPHeaders) MarshalFastJSON(w *fastjson.Writer) error
type HTTPRequest ¶
type HTTPRequest struct {
Body *HTTPRequestBody `json:"body,omitempty"`
Headers HTTPHeaders `json:"headers,omitempty"` // Non-ECS field.
ID string `json:"id,omitempty"`
Method string `json:"method,omitempty"`
Referrer string `json:"referrer,omitempty"`
Env KeyValueSlice `json:"env,omitempty"` // Non-ECS field.
Cookies KeyValueSlice `json:"cookies,omitempty"` // Non-ECS field.
}
func (*HTTPRequest) MarshalFastJSON ¶
func (v *HTTPRequest) MarshalFastJSON(w *fastjson.Writer) error
type HTTPRequestBody ¶
type HTTPRequestBody struct {
Original any `json:"original,omitempty"` // Non-ECS field.
}
func (*HTTPRequestBody) MarshalFastJSON ¶
func (v *HTTPRequestBody) MarshalFastJSON(w *fastjson.Writer) error
type HTTPResponse ¶
type HTTPResponse struct {
Finished *bool `json:"finished,omitempty"` // Non-ECS field.
HeadersSent *bool `json:"headers_sent,omitempty"` // Non-ECS field.
TransferSize *uint64 `json:"transfer_size,omitempty"` // Non-ECS field.
EncodedBodySize *uint64 `json:"encoded_body_size,omitempty"` // Non-ECS field.
DecodedBodySize *uint64 `json:"decoded_body_size,omitempty"` // Non-ECS field.
Headers HTTPHeaders `json:"headers,omitempty"` // Non-ECS field.
StatusCode int `json:"status_code,omitempty"`
}
func (*HTTPResponse) MarshalFastJSON ¶
func (v *HTTPResponse) MarshalFastJSON(w *fastjson.Writer) error
type Host ¶
type KeyValueSlice ¶
func (*KeyValueSlice) MarshalFastJSON ¶
func (s *KeyValueSlice) MarshalFastJSON(w *fastjson.Writer) error
type Kubernetes ¶
type Kubernetes struct {
Namespace string `json:"namespace,omitempty"`
Node KubernetesNode `json:"node,omitempty"`
Pod KubernetesPod `json:"pod,omitempty"`
}
func (*Kubernetes) MarshalFastJSON ¶
func (v *Kubernetes) MarshalFastJSON(w *fastjson.Writer) error
type KubernetesNode ¶
type KubernetesNode struct {
Name string `json:"name,omitempty"`
}
func (*KubernetesNode) MarshalFastJSON ¶
func (v *KubernetesNode) MarshalFastJSON(w *fastjson.Writer) error
type KubernetesPod ¶
func (*KubernetesPod) MarshalFastJSON ¶
func (v *KubernetesPod) MarshalFastJSON(w *fastjson.Writer) error
type Language ¶
type Log ¶
type LogOrigin ¶
type LogOrigin struct {
Function string `json:"function"`
File LogOriginFile `json:"file"`
}
type LogOriginFile ¶
func (*LogOriginFile) MarshalFastJSON ¶
func (v *LogOriginFile) MarshalFastJSON(w *fastjson.Writer) error
type LongtaskMetrics ¶
type LongtaskMetrics struct {
Count int `json:"count"`
Sum float64 `json:"sum"`
Max float64 `json:"max"`
}
func (*LongtaskMetrics) MarshalFastJSON ¶
func (v *LongtaskMetrics) MarshalFastJSON(w *fastjson.Writer) error
type Message ¶
type Message struct {
Body string `json:"body,omitempty"`
Age MessageAge `json:"age,omitempty"`
Queue MessageQueue `json:"queue,omitempty"`
RoutingKey string `json:"routing_key,omitempty"`
Headers HTTPHeaders `json:"headers,omitempty"`
}
type MessageAge ¶
type MessageAge struct {
Millis *uint64 `json:"ms,omitempty"`
}
func (*MessageAge) MarshalFastJSON ¶
func (v *MessageAge) MarshalFastJSON(w *fastjson.Writer) error
type MessageQueue ¶
type MessageQueue struct {
Name string `json:"name,omitempty"`
}
func (*MessageQueue) MarshalFastJSON ¶
func (v *MessageQueue) MarshalFastJSON(w *fastjson.Writer) error
type Metricset ¶
type Metricset struct {
Name string `json:"name,omitempty"`
Interval string `json:"interval,omitempty"`
Samples []MetricsetSample `json:"samples,omitempty"`
}
type MetricsetSample ¶
type MetricsetSample struct {
Name string
Type string
Unit string
Histogram Histogram
Summary SummaryMetric
Value float64
}
func (*MetricsetSample) MarshalFastJSON ¶
func (ms *MetricsetSample) MarshalFastJSON(w *fastjson.Writer) error
TODO(axw) update ingest pipelines to map metric samples to the top level of the document.
type Network ¶
type Network struct {
Connection NetworkConnection `json:"connection,omitempty"`
Carrier NetworkCarrier `json:"carrier,omitempty"`
}
type NetworkCarrier ¶
type NetworkCarrier struct {
Name string `json:"name,omitempty"`
MCC string `json:"mcc,omitempty"`
MNC string `json:"mnc,omitempty"`
ICC string `json:"icc,omitempty"`
}
func (*NetworkCarrier) MarshalFastJSON ¶
func (v *NetworkCarrier) MarshalFastJSON(w *fastjson.Writer) error
type NetworkConnection ¶
type NetworkConnection struct {
Type string `json:"type,omitempty"`
Subtype string `json:"subtype,omitempty"`
}
func (*NetworkConnection) MarshalFastJSON ¶
func (v *NetworkConnection) MarshalFastJSON(w *fastjson.Writer) error
type NumericLabel ¶
func (*NumericLabel) MarshalFastJSON ¶
func (v *NumericLabel) MarshalFastJSON(w *fastjson.Writer) error
type OS ¶
type Observer ¶
type Process ¶
type Process struct {
Title string `json:"title,omitempty"`
CommandLine string `json:"command_line,omitempty"`
Executable string `json:"executable,omitempty"`
Args []string `json:"args,omitempty"`
Thread ProcessThread `json:"thread,omitempty"`
Parent ProcessParent `json:"parent,omitempty"`
Pid int `json:"pid,omitempty"`
}
type ProcessParent ¶
type ProcessParent struct {
Pid uint32 `json:"pid,omitempty"`
}
func (*ProcessParent) MarshalFastJSON ¶
func (v *ProcessParent) MarshalFastJSON(w *fastjson.Writer) error
type ProcessThread ¶
func (*ProcessThread) MarshalFastJSON ¶
func (v *ProcessThread) MarshalFastJSON(w *fastjson.Writer) error
type Runtime ¶
type Service ¶
type Service struct {
Node *ServiceNode `json:"node,omitempty"`
Language *Language `json:"language,omitempty"`
Runtime *Runtime `json:"runtime,omitempty"`
Framework *Framework `json:"framework,omitempty"`
Origin *ServiceOrigin `json:"origin,omitempty"`
Target *ServiceTarget `json:"target,omitempty"`
Name string `json:"name,omitempty"`
Version string `json:"version,omitempty"`
Environment string `json:"environment,omitempty"`
}
type ServiceNode ¶
type ServiceNode struct {
Name string `json:"name,omitempty"`
}
func (*ServiceNode) MarshalFastJSON ¶
func (v *ServiceNode) MarshalFastJSON(w *fastjson.Writer) error
type ServiceOrigin ¶
type ServiceOrigin struct {
ID string `json:"id,omitempty"`
Name string `json:"name,omitempty"`
Version string `json:"version,omitempty"`
}
func (*ServiceOrigin) MarshalFastJSON ¶
func (v *ServiceOrigin) MarshalFastJSON(w *fastjson.Writer) error
type ServiceTarget ¶
type ServiceTarget struct {
Name string `json:"name,omitempty"`
Type string `json:"type"` // intentionally not omitempty
}
func (*ServiceTarget) MarshalFastJSON ¶
func (v *ServiceTarget) MarshalFastJSON(w *fastjson.Writer) error
type Source ¶
type Span ¶
type Span struct {
Message *Message `json:"message,omitempty"`
Composite *SpanComposite `json:"composite,omitempty"`
Destination *SpanDestination `json:"destination,omitempty"`
DB *DB `json:"db,omitempty"`
Sync *bool `json:"sync,omitempty"`
Kind string `json:"kind,omitempty"`
Action string `json:"action,omitempty"`
Subtype string `json:"subtype,omitempty"`
ID string `json:"id,omitempty"`
Type string `json:"type,omitempty"`
Name string `json:"name,omitempty"`
Stacktrace []StacktraceFrame `json:"stacktrace,omitempty"`
Links []SpanLink `json:"links,omitempty"`
SelfTime AggregatedDuration `json:"self_time,omitempty"`
RepresentativeCount float64 `json:"representative_count,omitempty"`
}
type SpanComposite ¶
type SpanComposite struct {
CompressionStrategy string `json:"compression_strategy"`
Count int `json:"count"`
Sum SpanCompositeSum `json:"sum"`
}
func (*SpanComposite) MarshalFastJSON ¶
func (v *SpanComposite) MarshalFastJSON(w *fastjson.Writer) error
type SpanCompositeSum ¶
type SpanCompositeSum struct {
US int64 `json:"us"`
}
func (*SpanCompositeSum) MarshalFastJSON ¶
func (v *SpanCompositeSum) MarshalFastJSON(w *fastjson.Writer) error
type SpanCount ¶
type SpanDestination ¶
type SpanDestination struct {
Service SpanDestinationService `json:"service"`
}
func (*SpanDestination) MarshalFastJSON ¶
func (v *SpanDestination) MarshalFastJSON(w *fastjson.Writer) error
type SpanDestinationService ¶
type SpanDestinationService struct {
Type string `json:"type,omitempty"`
Name string `json:"name,omitempty"`
Resource string `json:"resource,omitempty"`
ResponseTime AggregatedDuration `json:"response_time,omitempty"`
}
func (*SpanDestinationService) MarshalFastJSON ¶
func (v *SpanDestinationService) MarshalFastJSON(w *fastjson.Writer) error
type SpanLink ¶
type SpanLink struct {
Trace SpanLinkTrace `json:"trace,omitempty"`
Span SpanLinkSpan `json:"span,omitempty"`
}
type SpanLinkSpan ¶
type SpanLinkSpan struct {
ID string `json:"id"`
}
func (*SpanLinkSpan) MarshalFastJSON ¶
func (v *SpanLinkSpan) MarshalFastJSON(w *fastjson.Writer) error
type SpanLinkTrace ¶
type SpanLinkTrace struct {
ID string `json:"id"`
}
func (*SpanLinkTrace) MarshalFastJSON ¶
func (v *SpanLinkTrace) MarshalFastJSON(w *fastjson.Writer) error
type StacktraceFrame ¶
type StacktraceFrame struct {
Sourcemap *StacktraceFrameSourcemap `json:"sourcemap,omitempty"`
Original *StacktraceFrameOriginal `json:"original,omitempty"`
Context *StacktraceFrameContext `json:"context,omitempty"`
Line *StacktraceFrameLine `json:"line,omitempty"`
Filename string `json:"filename,omitempty"`
Classname string `json:"classname,omitempty"`
Module string `json:"module,omitempty"`
Function string `json:"function,omitempty"`
AbsPath string `json:"abs_path,omitempty"`
Vars KeyValueSlice `json:"vars,omitempty"`
LibraryFrame bool `json:"library_frame,omitempty"`
ExcludeFromGrouping bool `json:"exclude_from_grouping"`
}
func (*StacktraceFrame) MarshalFastJSON ¶
func (v *StacktraceFrame) MarshalFastJSON(w *fastjson.Writer) error
type StacktraceFrameContext ¶
type StacktraceFrameContext struct {
Pre []string `json:"pre,omitempty"`
Post []string `json:"post,omitempty"`
}
func (*StacktraceFrameContext) MarshalFastJSON ¶
func (v *StacktraceFrameContext) MarshalFastJSON(w *fastjson.Writer) error
type StacktraceFrameLine ¶
type StacktraceFrameLine struct {
Number *uint32 `json:"number,omitempty"`
Column *uint32 `json:"column,omitempty"`
Context string `json:"context,omitempty"`
}
func (*StacktraceFrameLine) MarshalFastJSON ¶
func (v *StacktraceFrameLine) MarshalFastJSON(w *fastjson.Writer) error
type StacktraceFrameOriginal ¶
type StacktraceFrameOriginal struct {
AbsPath string `json:"abs_path,omitempty"`
Filename string `json:"filename,omitempty"`
Classname string `json:"classname,omitempty"`
Lineno *uint32 `json:"lineno,omitempty"`
Colno *uint32 `json:"colno,omitempty"`
Function string `json:"function,omitempty"`
LibraryFrame bool `json:"library_frame,omitempty"`
}
func (*StacktraceFrameOriginal) MarshalFastJSON ¶
func (v *StacktraceFrameOriginal) MarshalFastJSON(w *fastjson.Writer) error
type StacktraceFrameSourcemap ¶
type StacktraceFrameSourcemap struct {
Error string `json:"error,omitempty"`
Updated bool `json:"updated,omitempty"`
}
func (*StacktraceFrameSourcemap) MarshalFastJSON ¶
func (v *StacktraceFrameSourcemap) MarshalFastJSON(w *fastjson.Writer) error
type SummaryMetric ¶
func (*SummaryMetric) MarshalFastJSON ¶
func (v *SummaryMetric) MarshalFastJSON(w *fastjson.Writer) error
type System ¶ added in v1.7.0
type System struct {
Process SystemProcess `json:"process,omitempty"`
Filesystem SystemFilesystem `json:"filesystem,omitempty"`
}
type SystemFilesystem ¶ added in v1.8.0
type SystemFilesystem struct {
MountPoint string `json:"mount_point,omitempty"`
}
func (*SystemFilesystem) MarshalFastJSON ¶ added in v1.8.0
func (v *SystemFilesystem) MarshalFastJSON(w *fastjson.Writer) error
type SystemProcess ¶ added in v1.7.0
type SystemProcess struct {
CPU SystemProcessCPU `json:"cpu,omitempty"`
State string `json:"state,omitempty"`
Cmdline string `json:"cmdline,omitempty"`
}
func (*SystemProcess) MarshalFastJSON ¶ added in v1.7.0
func (v *SystemProcess) MarshalFastJSON(w *fastjson.Writer) error
type SystemProcessCPU ¶ added in v1.7.0
type SystemProcessCPU struct {
StartTime string `json:"start_time,omitempty"`
}
func (*SystemProcessCPU) MarshalFastJSON ¶ added in v1.7.0
func (v *SystemProcessCPU) MarshalFastJSON(w *fastjson.Writer) error
type Transaction ¶
type Transaction struct {
SpanCount SpanCount `json:"span_count,omitempty"`
UserExperience *UserExperience `json:"experience,omitempty"`
Custom KeyValueSlice `json:"custom,omitempty"`
Marks map[string]map[string]float64 `json:"marks,omitempty"`
Message *Message `json:"message,omitempty"`
Type string `json:"type,omitempty"`
Name string `json:"name,omitempty"`
Result string `json:"result,omitempty"`
ID string `json:"id,omitempty"`
DurationHistogram Histogram `json:"duration.histogram,omitempty"`
DroppedSpansStats []DroppedSpanStats `json:"dropped_spans_stats,omitempty"`
ProfilerStackTraceIds []string `json:"profiler_stack_trace_ids,omitempty"`
DurationSummary SummaryMetric `json:"duration.summary,omitempty"`
RepresentativeCount float64 `json:"representative_count,omitempty"`
Sampled bool `json:"sampled,omitempty"`
Root bool `json:"root,omitempty"`
}
func (*Transaction) MarshalFastJSON ¶
func (v *Transaction) MarshalFastJSON(w *fastjson.Writer) error
type URL ¶
type URL struct {
Original string `json:"original,omitempty"`
Scheme string `json:"scheme,omitempty"`
Full string `json:"full,omitempty"`
Domain string `json:"domain,omitempty"`
Path string `json:"path,omitempty"`
Query string `json:"query,omitempty"`
Fragment string `json:"fragment,omitempty"`
Port int `json:"port,omitempty"`
}
type User ¶
type UserAgent ¶
type UserExperience ¶
type UserExperience struct {
CumulativeLayoutShift float64
FirstInputDelay float64
TotalBlockingTime float64
Longtask LongtaskMetrics
}
func (*UserExperience) MarshalFastJSON ¶
func (u *UserExperience) MarshalFastJSON(w *fastjson.Writer) error
Source Files
¶
- agent.go
- child.go
- client.go
- cloud.go
- container.go
- destination.go
- device.go
- document.go
- error.go
- event.go
- experience.go
- faas.go
- host.go
- http.go
- httpheader.go
- ip.go
- keyvalue.go
- kubernetes.go
- labels.go
- log.go
- marshal_fastjson.go
- message.go
- metricset.go
- network.go
- observer.go
- os.go
- parent.go
- process.go
- service.go
- session.go
- source.go
- span.go
- spanlink.go
- stacktrace.go
- system.go
- timestamp.go
- trace.go
- transaction.go
- url.go
- user.go
- useragent.go
Click to show internal directories.
Click to hide internal directories.